
clearvars
close('all')

load outputOfCleanScript_allmodels_alldates_12aug2016  %Change This. 

showsteps = 9;

gdpcolor = [0.85 0.85 0.85]; %Light grey
oilcolor = [0.2 0.3 0.5]; %Dark Blue
bpcolor = [0.4 0.4 0.4]; %Medium Grey
trcolor = [0.6 0.6 0.6]; %Dark Grey
miccolor_altni3 = [0.7 0.7 0.7]; %Yet Darker Grey
miccolor_ni3 = [0.3 0 0]; %Brick Red
hstscolor = [0.8 0 0.8]; %Purple

allcolor = [bpcolor;trcolor;hstscolor;miccolor_altni3;miccolor_ni3;gdpcolor;oilcolor];

allmodels = fields(datastruct);

gengdpfigs = 0;

if gengdpfigs == 1

allLabels = {'Error from Bond Premium','Error from Treasury Spread','Error from Consumer Confidence','Error from Housing','Error from GDP','Error from Oil'};    
figstartpoints = {'1990Q3','2007Q4'};
showmodels = allmodels;

if any(~ismember(figstartpoints,showstartpoints))
    error('One or more figstartpoints is not in showstartpoints')
end

if any(~ismember(showmodels,allmodels))
    error('One or more showmodel inputs is not in allmodels')
end

for istpt = 1:length(figstartpoints)
        
    use_stpt = figstartpoints{istpt};
    useInfoDateStr = datestr(addtodate(datenum(use_stpt,'yyyyqq'),-3,'month'),'yyyyqq');
    use_stptnum = find(strcmpi(allstartpoints,use_stpt));
        
    [use_year,use_mnt] = datevec(use_stpt,'yyyyqq');
    date_plot = datenum(use_year,use_mnt+(0:3:(showsteps-1)*3),1);
    date_disp = date_plot(1:2:end); 
    
    storemodels = cell(length(allmodels),1);
    
    storefigs = NaN(length(allmodels),1);
    storeaxisval = NaN(length(allmodels),4);
    storemainaxishandle = NaN(length(allmodels),1);
    storetitleaxishandle = NaN(length(allmodels),1);
    
    for imodel = 1:length(allmodels)
    
        usemodel = allmodels{imodel};
        dispmodel = usemodel;
        dispmodel(strfind(dispmodel,'_')) = repmat(' ',[1 length(strfind(dispmodel,'_'))]);   
        
        storemodels{imodel} = usemodel;
        
        gdpix_use = datastruct.(usemodel).gdpix;
        oilix_use = datastruct.(usemodel).oilix;
        bpix_use = datastruct.(usemodel).bpix;
        trix_use = datastruct.(usemodel).trix;
        micix_use = datastruct.(usemodel).micix;
        hstsix_use = datastruct.(usemodel).hstsix;

        if strcmpi(usemodel,'oil_gdp_mic_ni3')
            micni3_flag = 1;
        else
            micni3_flag = [];
        end
        
        if strcmpi(usemodel,'oil_gdp_mic_altni3')
            micaltni3_flag = 1;
        else
            micaltni3_flag = [];
        end        
    
        cumgdperror = datastruct.(usemodel).cumgdperror(1:showsteps,gdpix_use,istpt);
        cumoilerror = datastruct.(usemodel).cumoilerror(1:showsteps,gdpix_use,istpt);
        cumbperror = datastruct.(usemodel).cumbperror(1:showsteps,gdpix_use,istpt);
        cumtrerror = datastruct.(usemodel).cumtrerror(1:showsteps,gdpix_use,istpt);
        cummicerror = datastruct.(usemodel).cummicerror(1:showsteps,gdpix_use,istpt);        
        cumhstserror = datastruct.(usemodel).cumhstserror(1:showsteps,gdpix_use,istpt);        

        cumtotalerror = datastruct.(usemodel).cumtotalerror(1:showsteps,gdpix_use,istpt);      
        
        allerror = [cumbperror cumtrerror cummicerror cumgdperror cumoilerror];
        useerror = allerror(:,~[isempty(bpix_use) isempty(trix_use) isempty(micix_use) isempty(gdpix_use) isempty(oilix_use)]);        
        usecolor = allcolor(~[isempty(bpix_use) isempty(trix_use) isempty(micaltni3_flag) isempty(micni3_flag) isempty(gdpix_use) isempty(oilix_use)],:); 
        uselabel = allLabels(~[isempty(bpix_use) isempty(trix_use) isempty(micix_use) isempty(gdpix_use) isempty(oilix_use)]);         
        
        negerror = zeros(size(useerror));
        poserror = zeros(size(useerror));
        for zz = 1:size(useerror,1)
            negerror(zz,useerror(zz,:)<0) = useerror(zz,useerror(zz,:)<0);
            poserror(zz,useerror(zz,:)>=0) = useerror(zz,useerror(zz,:)>=0);            
        end
        
        storefigs(imodel) = figure;
        plot(date_plot,cumtotalerror,'kp','markersize',15,'markerfacecolor','k');
        hold on
        bar(date_plot,negerror,'stacked');
        bar(date_plot,poserror,'stacked');
        colormap(usecolor);
        plot(date_plot,cumtotalerror,'kp','markersize',15,'markerfacecolor','k');
        holdaxis = axis;
        set(gca,'xtick',date_disp)
        datetick('x','QQ-YY','keepticks')
        axis(holdaxis)
        storeaxisval(imodel,:) = axis;        
        storemainaxishandle(imodel) = gca;
        
        legend(char('Total Error',char(uselabel)),'location','southoutside')
        storetitleaxishandle(imodel) = axes('pos',[0 1 1 1],'visible','off');
            text(0.5,-.05,'Cumulative GDP Forecast Error Decomposition',...
                'horizontalalignment','center','verticalalignment','bottom')
            text(0.5,-.05,['Model: ' dispmodel '      Forecast based on lags ending: ' useInfoDateStr],...
                'horizontalalignment','center','verticalalignment','top')        
        
        
    end
    
    useaxis = [date_plot(1)-50 date_plot(end)+50 min(storeaxisval(:,3)) max(storeaxisval(:,4))];
    
    for imodel = 1:length(allmodels)
        
        figure(storefigs(imodel));
        axes(storemainaxishandle(imodel))
        axis(useaxis);
        axes(storetitleaxishandle(imodel))
        orient('landscape')
        print('-dpdf',['histdecompfig_' useInfoDateStr '_' storemodels{imodel}])
        
    end
    
end

end

gengdpfigs_subplot = 1;

if gengdpfigs_subplot == 1

allLabels = {'Error from Bond Premium','Error from Treasury Spread','Error from Consumer Confidence','Error from GDP','Error from Oil'};    
figstartpoints = showstartpoints;
% figstartpoints = {'1990Q3'};

%Needs to be 4 models
showmodels = {'oil_gdp_ni3','oil_gdp_bp1_altni3','oil_gdp_mic_ni3','oil_gdp_mic_altni3'};

if any(~ismember(figstartpoints,showstartpoints))
    error('One or more figstartpoints is not in showstartpoints')
end

if any(~ismember(showmodels,allmodels))
    error('One or more showmodel inputs is not in allmodels')
end

for istpt = 1:length(figstartpoints)
        
    use_stpt = figstartpoints{istpt};
    useInfoDateStr = datestr(addtodate(datenum(use_stpt,'yyyyqq'),-3,'month'),'yyyyqq');
    use_stptnum = find(strcmpi(allstartpoints,use_stpt));
        
    [use_year,use_mnt] = datevec(use_stpt,'yyyyqq');
    date_plot = datenum(use_year,use_mnt+(0:3:(showsteps-1)*3),1);
    date_disp = date_plot(1:2:end); 
    
    storemodels = cell(length(allmodels),1);
    
    storefigs = NaN(length(allmodels),1);
    storeaxisval = NaN(length(allmodels),4);
    storemainaxishandle = NaN(length(allmodels),1);
    storetitleaxishandle = NaN(length(allmodels),1);
    
    figure
    subplot(2,2,1)
    
    for imodel = 1:length(showmodels)
    
        usemodel = showmodels{imodel};
        dispmodel = usemodel;
        dispmodel(strfind(dispmodel,'_')) = repmat(' ',[1 length(strfind(dispmodel,'_'))]);   
        
        storemodels{imodel} = usemodel;
        
        gdpix_use = datastruct.(usemodel).gdpix;
        oilix_use = datastruct.(usemodel).oilix;
        bpix_use = datastruct.(usemodel).bpix;
        trix_use = datastruct.(usemodel).trix;
        micix_use = datastruct.(usemodel).micix;
        
        if strcmpi(usemodel,'oil_gdp_mic_ni3')
            micni3_flag = 1;
        else
            micni3_flag = [];
        end
        
        if strcmpi(usemodel,'oil_gdp_mic_altni3')
            micaltni3_flag = 1;
        else
            micaltni3_flag = [];
        end        
    
        cumgdperror = datastruct.(usemodel).cumgdperror(1:showsteps,gdpix_use,istpt);
        cumoilerror = datastruct.(usemodel).cumoilerror(1:showsteps,gdpix_use,istpt);
        cumbperror = datastruct.(usemodel).cumbperror(1:showsteps,gdpix_use,istpt);
        cumtrerror = datastruct.(usemodel).cumtrerror(1:showsteps,gdpix_use,istpt);
        cummicerror = datastruct.(usemodel).cummicerror(1:showsteps,gdpix_use,istpt);        
        cumtotalerror = datastruct.(usemodel).cumtotalerror(1:showsteps,gdpix_use,istpt);      
        
        allerror = [cumbperror cumtrerror cummicerror cumgdperror cumoilerror];
        allerror(isnan(allerror)) = zeros(sum(isnan(allerror(:)),1),1)+.0000000001;
        useerror = allerror(:,~[isempty(bpix_use) isempty(trix_use) isempty(micix_use) isempty(gdpix_use) isempty(oilix_use)]);       
        usecolor = allcolor(~[isempty(bpix_use) isempty(trix_use) isempty(micaltni3_flag) isempty(micni3_flag) isempty(gdpix_use) isempty(oilix_use)],:); 
        uselabel = allLabels(~[isempty(bpix_use) isempty(trix_use) isempty(micix_use) isempty(gdpix_use) isempty(oilix_use)]);   
        
        useerror = allerror;
        usecolor = allcolor;
        uselabel = allLabels;
        
        negerror = zeros(size(useerror));
        poserror = zeros(size(useerror));
        for zz = 1:size(useerror,1)
            negerror(zz,useerror(zz,:)<0) = useerror(zz,useerror(zz,:)<0);
            poserror(zz,useerror(zz,:)>=0) = useerror(zz,useerror(zz,:)>=0);            
        end
        
        subplot(2,2,imodel);
        plot(date_plot,cumtotalerror,'kp','markersize',15,'markerfacecolor','k');
        hold on
        bar(date_plot,negerror,'stacked');
        bar(date_plot,poserror,'stacked');
        colormap(usecolor);
        plot(date_plot,cumtotalerror,'kp','markersize',15,'markerfacecolor','k');
        holdaxis = axis;
        set(gca,'xtick',date_disp)
        datetick('x','QQ-YY','keepticks')
        axis(holdaxis)
        storeaxisval(imodel,:) = axis;        
        storemainaxishandle(imodel) = gca;
        
        title(dispmodel)
        
%         legend(char('Total Error',char(uselabel)),'location','southoutside')      
        
        
    end
    
    useaxis = [date_plot(1)-50 date_plot(end)+50 min(storeaxisval(:,3)) max(storeaxisval(:,4))];
    
    for imodel = 1:length(showmodels)
        
        subplot(2,2,imodel);
        axis(useaxis);
        if imodel == length(showmodels)
            legHandle = legend([{'Total Error'},uselabel],'orientation','vertical');
            holdPosition = get(legHandle,'position');
            set(legHandle,'position',[0.5-(holdPosition(3)/2) -0.065 holdPosition(3:4)])
        end
        
    end
    
    storetitleaxishandle(imodel) = axes('pos',[0 1 1 1],'visible','off');
        text(0.5,-.03,'Cumulative GDP Forecast Error Decomposition',...
            'horizontalalignment','center','verticalalignment','bottom')
        text(0.5,-.03,['Forecast based on lags ending: ' useInfoDateStr],...
            'horizontalalignment','center','verticalalignment','top')   
        
    orient landscape
    print('-dpdf',['subplots_histdecomp_' useInfoDateStr])
    
end

end

genoilcnrtbcompfig = 1;

if genoilcnrtbcompfig == 1

for idate = 1:length(infosetdates)
    
    useInfoDateStr = infosetdates{idate};
    useStartDateStr = showstartpoints{idate};
    stpt_indexnum = find(strcmpi(allstartpoints,useStartDateStr));
    
    [yr,mnt] = datevec(useStartDateStr,'yyyyqq');
    plotDateNum = datenum(yr,mnt:3:mnt+3*(showsteps-1),1);
    
    dispmodels = {'oil_gdp_ni3','oil_gdp_bp1_altni3','oil_gdp_travg_altni3','oil_gdp_mic_altni3','oil_gdp_mic_ni3'};
    
    plotBarData = NaN(showsteps,length(dispmodels));
    modelLabel = cell(length(dispmodels),1);
    
    for imodel = 1:length(dispmodels)
        
        usemodel = dispmodels{imodel};
        gdpix = datastruct.(usemodel).gdpix;
        plotBarData(:,imodel) = datastruct.(usemodel).cumoilerror(1:showsteps,gdpix,idate);
        tmpModelLabel = usemodel;
        tmpModelLabel(strfind(tmpModelLabel,'_')) = repmat(' ',[length(strfind(tmpModelLabel,'_')) 1]);
        modelLabel{imodel} = tmpModelLabel;
        
    end
    
    figure
    bar(plotDateNum,plotBarData)
    colormap([oilcolor;bpcolor;trcolor;miccolor_altni3;miccolor_ni3]);    
    legend(char(modelLabel),'location','southoutside')
    holdAxis = axis;
    set(gca,'xtick',plotDateNum)
    datetick('x','YYYYQQ','keepticks')
    axis([plotDateNum(1)-50 plotDateNum(end)+50 holdAxis(3:4)]);
    titleaxis = axes('pos',[0 1 1 1],'visible','off');
        text(0.5,-.05,'Oil Contribution to Cumulative GDP Forecast Error',...
            'horizontalalignment','center','verticalalignment','bottom')
        text(0.5,-.05,['Forecast based on lags ending: ' useInfoDateStr],...
            'horizontalalignment','center','verticalalignment','top')
    orient landscape
    print('-dpdf',['oilcntrb_histdecomp_' useInfoDateStr])
    
    
end

end