clearvars

%Set table options
showInfoSetDates = {'1979Q1','1980Q4','1990Q2','1995Q4','1999Q4','2004Q2','2007Q2'};
showSteps = [4 8];
showModels_ni3 = {'oil_gdp_ni3','oil_gdp_bp1_altni3','oil_gdp_travg_altni3','oil_gdp_mic_altni3','oil_gdp_bp1_travg_mic_altni3'};
showModels_lin = {'oil_gdp','oil_gdp_bp1','oil_gdp_travg','oil_gdp_mic','oil_gdp_bp1_travg_mic'};
modelLabels_ni3 = {'Baseline Model','Excess bond premium added','Term Spread added','Consumer confidence added (no/ NI term)','All three variables added'};
modelLabels_lin = {'Baseline Model','Excess bond premium added','Term Spread added','Consumer confidence added','All three variables added'};
tableTitle_2A_left = 'Table 2a: Total Forecast Error in the ';
tableTitle_2A_right = ' during Oil Price Surges';
tableTitle_2B_left = 'Table 2b: Decomposition due to Oil Price Shocks in the ';
tableTitle_2B_right = ' during Oil Price Surges';
tableTitle_2C_left = 'Table 2c: Decomposition due to GDP Shocks in the ';
tableTitle_2C_right = ' during Oil Price Surges';

%Load in data
dataLoad = load('outputOfCleanScriptVarV04_empdist_paperstartpoints_01apr2014');

%Check option inputs
if any(~ismember(showInfoSetDates,dataLoad.infosetdates))
    error('One or more info set dates for table 2 is not available in the data set loaded.')
end

showModels = [showModels_ni3;showModels_lin];
modelLabels = [modelLabels_ni3;modelLabels_lin];

if any(~ismember(showModels,dataLoad.allmodels))
    error('One or more models for table 2 is not available in the data set loaded.')
end

if length(showModels)~=length(modelLabels)
    error('Unequal number of models and model labels in table 2.')
end

nModels = length(showModels);
nShowSteps = length(showSteps);
nShowDates = length(showInfoSetDates);
[~,showDates_index] = intersect(dataLoad.infosetdates,showInfoSetDates,'stable');
rezultzout = NaN(7,5,2,2);


for subTable = 1:2
    if subTable == 1
        table_letter = 'a';
        usevar = 'cumtotalerror';        
        useTableTitle_left = tableTitle_2A_left;
        useTableTitle_right = tableTitle_2A_right;
    elseif subTable == 2
        table_letter = 'b';
        usevar = 'cumoilerror';        
        useTableTitle_left = tableTitle_2B_left;
        useTableTitle_right = tableTitle_2B_right;
    elseif subTable == 3
        table_letter = 'c';
        usevar = 'cumgdperror';        
        useTableTitle_left = tableTitle_2C_left;
        useTableTitle_right = tableTitle_2C_right;
    end
    
    for modelType = 1
        if modelType == 1
            useModels = showModels_ni3;
            useModelLabels = modelLabels_ni3;
            modelStub = 'ni3';
            modelName = 'Net Oil Price Increase Model';
        elseif modelType == 2
            useModels = showModels_lin;
            useModelLabels = modelLabels_lin;            
            modelStub = 'lin';
            modelName = 'Linear Model';
        end
        
        %Outline:
        %Row 1: Title
        %Row 2: Labels
        %Row 3 - end: Data
        %Column 1: Date Labels
        %Column 2 - end: Data
        outtable = cell(nShowDates+3,length(useModels)*length(showSteps)+1);
        
        tableTitle = [useTableTitle_left modelName useTableTitle_right];
        outtable(1,1) = {tableTitle};
        outtable(2,1) = {'Starting date'};
        outtable(3+(1:nShowDates),1) = showInfoSetDates; %Fill in date labels        
        
        for imodel = 1:length(useModels)
            tmp_usemodel = useModels{imodel};
            gdpix = dataLoad.datastruct.(tmp_usemodel).gdpix;
    
            outtable(2,1+(imodel-1)*nShowSteps+1) = useModelLabels(imodel);
    
            for istep = 1:nShowSteps
                usestep = showSteps(istep);
                use_data = squeeze(dataLoad.datastruct.(tmp_usemodel).(usevar)(usestep,gdpix,showDates_index));
        
                outtable(3,1+(imodel-1)*nShowSteps+istep) = num2cell(usestep);
                outtable(3+(1:nShowDates),1+(imodel-1)*nShowSteps+istep) = num2cell(100*use_data);
                
               rezultzout(:,imodel,subTable,istep) =  100*use_data;
            end
        end
        
        outtable_t = outtable'; %Transpose for output - Matlab is column-major, so to output appropriately must transpose first
        outtable(cellfun(@(x) isempty(x),outtable_t)) = {''}; %Feed in empty string character for empty cells
        fmtarray = cell(size(outtable_t)); %Preallocate array for format output
        fmtarray(cellfun(@(x) ischar(x),outtable_t)) = {'%s,'}; %Strings, including empty string
        fmtarray(cellfun(@(x) isfloat(x),outtable_t)) = {'%f,'}; %Numbers
        fmtarray(end,:) = cellfun(@(x) [x(1:end-1) '\n'],fmtarray(end,:),'UniformOutput',false); %Last row of transposed table (last column of table) get new line character rather than comma
        fileID = fopen(['rjvtable2' table_letter '_' modelStub '_unformatted.csv'],'wt'); %Open file w/ write permision
        fprintf(fileID,[fmtarray{:}],outtable_t{:}); %Put fmtarray{:} in brackets, but outtable{:} open to get proper functionality
        fclose('all'); %Close all files        
        
    end
end
    


figure
gryz = linspace(0.3,0.9,5);

    colormap([gryz' gryz' gryz'])
hb = bar(rezultzout(:,:,2,2))
xxData = get(get(hb(length(hb)),'Children'),'XData');
hold off
plot(mean(xxData(:,4)),rezultzout(4,end,1,2),'kp','markerfacecolor','k')
hold on
plot(3,0,'w-')
hold on
hb = bar(rezultzout(:,:,2,2))


for zx=1:length(hb); 
xxData = get(get(hb(zx),'Children'),'XData');
       barCenters = mean(unique(xxData,'rows'))
       plot(barCenters,rezultzout(:,zx,1,2),'kp','markerfacecolor','k')
   
end
bar(rezultzout(:,:,1,2),'w')
bar(rezultzout(:,:,2,2))
set(gca,'xticklabel',char('79Q1','80Q4','90Q2','95Q4','99Q4','04Q2','07Q2'));
hold on

for zx=1:length(hb); 
xxData = get(get(hb(zx),'Children'),'XData');
       barCenters = mean(unique(xxData,'rows'))
       plot(barCenters,rezultzout(:,zx,1,2),'kp','markerfacecolor','k')
   
end
title('Contribution of Oil Price Shocks To 8 Quarters-Ahead Forecast Errors in Net Increase Model')
legend('Total Error','Contribution from Model with','Oil and GDP','Oil,GDP, and Bond Premium','Oil,GDP, and T-Bill Spread','Oil,GDP, and Consumer Confidence','All Five Variables','Location','Southeast')
legend boxoff
xlabel('Starting Date')
keyboard
 print -dpdf GraphicalTable2NImodel8quarters


 
 
figure
gryz = linspace(0.3,0.9,5);

    colormap([gryz' gryz' gryz'])
hb = bar(rezultzout(:,:,2,1))
xxData = get(get(hb(length(hb)),'Children'),'XData');
hold off
plot(mean(xxData(:,4)),rezultzout(4,end,1,1),'kp','markerfacecolor','k')
hold on
plot(3,0,'w-')
hold on
hb = bar(rezultzout(:,:,2,1))


for zx=1:length(hb); 
xxData = get(get(hb(zx),'Children'),'XData');
       barCenters = mean(unique(xxData,'rows'))
       plot(barCenters,rezultzout(:,zx,1,1),'kp','markerfacecolor','k')
   
end
bar(rezultzout(:,:,1,1),'w')
bar(rezultzout(:,:,2,1))
set(gca,'xticklabel',char('79Q1','80Q4','90Q2','95Q4','99Q4','04Q2','07Q2'));
hold on

for zx=1:length(hb); 
xxData = get(get(hb(zx),'Children'),'XData');
       barCenters = mean(unique(xxData,'rows'))
       plot(barCenters,rezultzout(:,zx,1,1),'kp','markerfacecolor','k')
   
end
title('Contribution of Oil Price Shocks To 4 Quarters-Ahead Forecast Errors in Net Increase Model')
legend('Total Error','Contribution from Model with','Oil and GDP','Oil,GDP, and Bond Premium','Oil,GDP, and T-Bill Spread','Oil,GDP, and Consumer Confidence','All Five Variables','Location','Southeast')
legend boxoff
xlabel('Starting Date')
 print -dpdf GraphicalTable2NImodel4quarters


