clearvars

%Set table options
recessionDates = {'1979Q4','1981Q2','1990Q3','2001Q1','2007Q4'};
nonRecessionDates = {'1996Q3','2004Q4'};
showStep = 9;
showModels = {'oil_gdp_ni3','oil_gdp_net3','oil_gdp_asy3'};
modelLabels = {'Net Increase','Net Change','Asymmetric Net Change'};
tableTitle = 'Table 2: Percent of Forecast Error due to Oil Price Shocks in the Net Oil Price Increase Model during Oil Price Surges';

%Load in data
dataLoad = load('outputOfCleanScript_OilGDPonly_alldates_extramodels_29apr2014');


%Check option inputs
showInfoSetDates = [recessionDates, nonRecessionDates];
if any(~ismember(showInfoSetDates,dataLoad.infosetdates))
    error('One or more info set dates for table 3 is not available in the data set loaded.')
end

if any(~ismember(showModels,dataLoad.allmodels))
    error('One or more models for table 3 is not available in the data set loaded.')
end

% if any(ismember(showModels,dataLoad.linmodels))
%     error('One or more models for table 3 is a linear model.')
% end

if length(showModels)~=length(modelLabels)
    error('Unequal number of models and model labels in table 3.')
end

if ~isscalar(showStep)
    error('Table 3 - must choose 1 step to show.')
end

nModels = length(showModels);
nRecDates = length(recessionDates);
[~,recDates_index] = intersect(dataLoad.infosetdates,recessionDates,'stable');
nNonRecDates = length(nonRecessionDates);
[~,nonRecDates_index] = intersect(dataLoad.infosetdates,nonRecessionDates,'stable');
nShowDates = length(showInfoSetDates);

%Outline:
%Row 1 - Title
%Row 2 - Column Numbers
%Row 3 - Labels
%Row 4 on - data
%Column 1 - Episodes
%Column 2 - Dates
%Columns 3 on - models & data
outtable = cell(nShowDates+5,nModels+2);

outtable(1,1) = {tableTitle};
outtable(3,1) = {'Episodes'};
outtable(4,1) = {'U.S. Recession'};
outtable(3+nRecDates+1,1) = {'Non U.S. Recession'};
outtable(3+nShowDates+1,1) = {'Mean for net oil price increase episodes before recessions only'};
outtable(3+nShowDates+2,1) = {'Mean for all net oil price increase episodes'};

outtable(3,2) = {'Starting date'};
outtable(3+(1:nRecDates),2) = recessionDates;
outtable(3+nRecDates+(1:nNonRecDates),2) = nonRecessionDates;

for imodel = 1:nModels
    
    outtable(2,imodel+2) = {['(' num2str(imodel) ')']};
    outtable(3,imodel+2) = modelLabels(imodel);
    
    usemodel = showModels{imodel};
    
    underscore_index = strfind(usemodel,'_');
    usemodel_lin = usemodel(1:underscore_index(end)-1);
    
    gdpix = dataLoad.datastruct.(usemodel).gdpix;
    
    ni3_mspe_rec = squeeze(dataLoad.datastruct.(usemodel).cummserror(showStep,gdpix,recDates_index));
    lin_mspe_rec = squeeze(dataLoad.datastruct.(usemodel_lin).cummserror(showStep,gdpix,recDates_index));
    
    ni3_mspe_nonrec = squeeze(dataLoad.datastruct.(usemodel).cummserror(showStep,gdpix,nonRecDates_index));
    lin_mspe_nonrec = squeeze(dataLoad.datastruct.(usemodel_lin).cummserror(showStep,gdpix,nonRecDates_index));
    
    ni3_mspe_all = [ni3_mspe_rec; ni3_mspe_nonrec];
    lin_mspe_all = [lin_mspe_rec; lin_mspe_nonrec];
    
    outtable(3+(1:nRecDates),2+imodel) = num2cell(ni3_mspe_rec./lin_mspe_rec);
    outtable(3+nRecDates+(1:nNonRecDates),2+imodel) = num2cell(ni3_mspe_nonrec./lin_mspe_nonrec);
    outtable(3+nShowDates+1,2+imodel) = num2cell(mean(ni3_mspe_rec./lin_mspe_rec));
    outtable(3+nShowDates+2,2+imodel) = num2cell(mean(ni3_mspe_all./lin_mspe_all));
    
end

outtable_t = outtable'; %Transpose for output - Matlab is column-major, so to output appropriately must transpose first
outtable(cellfun(@(x) isempty(x),outtable_t)) = {''}; %Feed in empty string character for empty cells
fmtarray = cell(size(outtable_t)); %Preallocate array for format output
fmtarray(cellfun(@(x) ischar(x),outtable_t)) = {'%s,'}; %Strings, including empty string
fmtarray(cellfun(@(x) isfloat(x),outtable_t)) = {'%f,'}; %Numbers
fmtarray(end,:) = cellfun(@(x) [x(1:end-1) '\n'],fmtarray(end,:),'UniformOutput',false); %Last row of transposed table (last column of table) get new line character rather than comma
fileID = fopen('table4_extramodels_unformatted.csv','wt'); %Open file w/ write permision
fprintf(fileID,[fmtarray{:}],outtable_t{:}); %Put fmtarray{:} in brackets, but outtable{:} open to get proper functionality
fclose('all'); %Close all files 


